@@ -58,6 +58,16 @@ bool Chm::loadFile( const QString& name )
     tableOfContents_.clear(); 
     chm_.parseTableOfContents( &tableOfContents_ );
 
+    urlMap_.clear();
+
+    for( int i = 0; i < tableOfContents_.count(); ++i )
+    { 
+
+      QString url = tableOfContents_[i].urls.join("|");
+      urlMap_.insert( url, i );
+    }
+
+
     fileInfo_.setFile( name );
 
     lastDocDir_ = fileInfo_.absoluteDir().absolutePath();
@@ -426,3 +436,10 @@ bool Chm::storeStringList( const QString& fileName, const QStringList& list )
   return result;
 }
 
+
+///////////////////////////////////////////////////////////////////////////////
+size_t Chm::getUrlPageNum( const QString& url ) const
+{
+  return urlMap_.value( url, 0 );
+}
+
