@@ -38,6 +38,9 @@ class Chm
     LCHMFile& chm() { return chm_; }
     bool loadFile( const QString& name );
 
+
+    size_t getUrlPageNum( const QString& url ) const;
+
     
     ///////////////////////////////////////////////////////////////////////////
     QString getTopicByUrl( const QString& url  ) const 
@@ -107,6 +110,10 @@ class Chm
     LCHMSearchEngine se_;
 
     ChmEntryList tableOfContents_;
+    typedef QMap< QString, size_t> tocmap_t;
+    tocmap_t urlMap_;
+
+
 
     QStringList resultList_;
     QStringList bookmarks_;
