@@ -19,11 +19,13 @@
 #ifndef __CONTENTS_WIDGET_H__
 #define __CONTENTS_WIDGET_H__
 
+
+
+#if 0
 #include <qwidget.h>
 #include <qlistwidget.h>
 #include "chmtypes.h"
 
-
 class ContentsWidget : public QWidget
 {
   Q_OBJECT
@@ -45,6 +47,41 @@ class ContentsWidget : public QWidget
      QListWidget* contents_;
 
 };
+#else
+#include <QDialog>
+class Chm;
+class QSize;
+class QWidget;
+class QPoint;
+class QListWidget;
+class QWidget;
+class QVBoxLayout;
 
+class TocDialog : public QDialog
+{
+  Q_OBJECT
+
+
+  public:
+    static int doToc( Chm& chm, const QPoint& pos, const QSize& sz, QWidget* parent = 0 );
+
+
+  private:
+    TocDialog( QWidget* parent = 0 );
+    ~TocDialog();
+
+    bool loadToc( const Chm& chm );
+
+  private slots:
+    void chooseTocItem( );
+    void abortToc();
+
+  private:
+    int index_;
+    QVBoxLayout* vbox_;
+    QListWidget* toc_;
+
+};
+#endif
 
 #endif
